==> invoice-client-4.1.56-20240305.094845-14-sources.jar: com/xforceplus/seller/invoice/client/model/adapter/SellerInvoice.java <==
package com.xforceplus.seller.invoice.client.model.adapter;

import com.google.common.collect.Lists;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

@SuppressWarnings({ "all", "unchecked", "rawtypes" })
public class SellerInvoice implements Serializable {

    private static final long serialVersionUID = -13752717;

    private String pid = "";
    private String settlementNo = "";
    private String invoiceType = "";
    private String invoiceCode = "";
    private String invoiceNo = "";
    private String paperDrewDate = "";
    private String sellerTaxNo = "";
    private String sellerName = "";
    private String sellerAddrTel = "";
    private String sellerAddress = "";
    private String sellerTel = "";
    private String sellerBankInfo = "";
    private String sellerBankName = "";
    private String sellerBankAccount = "";
    private String purchaserTaxNo = "";
    private String purchaserName = "";
    private String purchaserAddrTel = "";
    private String purchaserAddress = "";
    private String purchaserTel = "";
    private String purchaserBankInfo = "";
    private String purchaserBankName = "";
    private String purchaserBankAccount = "";
    private BigDecimal taxRate;
    private BigDecimal amountWithoutTax;
    private BigDecimal taxAmount;
    private BigDecimal amountWithTax;
    private String cipherTextTwoCode = "";
    private String cipherText = "";
    private String remark = "";
    private String cashierName = "";
    private String checkerName = "";
    private String invoicerName = "";
    private String checkCode = "";
    private String machineCode = "";
    private String status = "";
    private String displayPriceQuality = "";
    private String originInvoiceNo = "";
    private String originInvoiceCode = "";
    private String redNotificationNo = "";
    private String saleListFileFlag = "";
    private String pdfPath = "";
    private String processCode = "";
    private String processFlag = "";
    private String processRemark = "";
    /**
     * 2018年3月27日11:26:41 ykq 开票结算单新增SystemOrig
     * 发票协同需携带SystemOrig
     */
    private String systemOrig = "";
    private String ofdUrl;
    private String xmlUrl;
    private List<SellerInvoiceItem> details = Lists.newArrayList();
    private String specialFlag;
    private List specialAdditions;

    public SellerInvoice() {

    }

    public String getProcessCode() {
        return processCode;
    }

    public void setProcessCode(String processCode) {
        this.processCode = processCode;
    }

    public String getOfdUrl() {
        return ofdUrl;
    }

    public void setOfdUrl(String ofdUrl) {
        this.ofdUrl = ofdUrl;
    }

    public String getXmlUrl() {
        return xmlUrl;
    }

    public void setXmlUrl(String xmlUrl) {
        this.xmlUrl = xmlUrl;
    }

    public String getPid() {
        return pid;
    }

    public void setPid(String pid) {
        this.pid = pid;
    }

    public String getSettlementNo() {
        return settlementNo;
    }

    public void setSettlementNo(String settlementNo) {
        this.settlementNo = settlementNo;
    }

    public String getInvoiceType() {
        return invoiceType;
    }

    public void setInvoiceType(String invoiceType) {
        this.invoiceType = invoiceType;
    }

    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }

    public String getInvoiceNo() {
        return invoiceNo;
    }

    public void setInvoiceNo(String invoiceNo) {
        this.invoiceNo = invoiceNo;
    }

    public String getPaperDrewDate() {
        return paperDrewDate;
    }

    public void setPaperDrewDate(String paperDrewDate) {
        this.paperDrewDate = paperDrewDate;
    }

    public String getSellerTaxNo() {
        return sellerTaxNo;
    }

    public void setSellerTaxNo(String sellerTaxNo) {
        this.sellerTaxNo = sellerTaxNo;
    }

    public String getSellerName() {
        return sellerName;
    }

    public void setSellerName(String sellerName) {
        this.sellerName = sellerName;
    }

    public String getSellerAddrTel() {
        return sellerAddrTel;
    }

    public void setSellerAddrTel(String sellerAddrTel) {
        this.sellerAddrTel = sellerAddrTel;
    }

    public String getSellerAddress() {
        return sellerAddress;
    }

    public void setSellerAddress(String sellerAddress) {
        this.sellerAddress = sellerAddress;
    }

    public String getSellerTel() {
        return sellerTel;
    }

    public void setSellerTel(String sellerTel) {
        this.sellerTel = sellerTel;
    }

    public String getSellerBankInfo() {
        return sellerBankInfo;
    }

    public void setSellerBankInfo(String sellerBankInfo) {
        this.sellerBankInfo = sellerBankInfo;
    }

    public String getSellerBankName() {
        return sellerBankName;
    }

    public void setSellerBankName(String sellerBankName) {
        this.sellerBankName = sellerBankName;
    }

    public String getSellerBankAccount() {
        return sellerBankAccount;
    }

    public void setSellerBankAccount(String sellerBankAccount) {
        this.sellerBankAccount = sellerBankAccount;
    }

    public String getPurchaserTaxNo() {
        return purchaserTaxNo;
    }

    public void setPurchaserTaxNo(String purchaserTaxNo) {
        this.purchaserTaxNo = purchaserTaxNo;
    }

    public String getPurchaserName() {
        return purchaserName;
    }

    public void setPurchaserName(String purchaserName) {
        this.purchaserName = purchaserName;
    }

    public String getPurchaserAddrTel() {
        return purchaserAddrTel;
    }

    public void setPurchaserAddrTel(String purchaserAddrTel) {
        this.purchaserAddrTel = purchaserAddrTel;
    }

    public String getPurchaserAddress() {
        return purchaserAddress;
    }

    public void setPurchaserAddress(String purchaserAddress) {
        this.purchaserAddress = purchaserAddress;
    }

    public String getPurchaserTel() {
        return purchaserTel;
    }

    public void setPurchaserTel(String purchaserTel) {
        this.purchaserTel = purchaserTel;
    }

    public String getPurchaserBankInfo() {
        return purchaserBankInfo;
    }

    public void setPurchaserBankInfo(String purchaserBankInfo) {
        this.purchaserBankInfo = purchaserBankInfo;
    }

    public String getPurchaserBankName() {
        return purchaserBankName;
    }

    public void setPurchaserBankName(String purchaserBankName) {
        this.purchaserBankName = purchaserBankName;
    }

    public String getPurchaserBankAccount() {
        return purchaserBankAccount;
    }

    public void setPurchaserBankAccount(String purchaserBankAccount) {
        this.purchaserBankAccount = purchaserBankAccount;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public BigDecimal getAmountWithoutTax() {
        return amountWithoutTax;
    }

    public void setAmountWithoutTax(BigDecimal amountWithoutTax) {
        this.amountWithoutTax = amountWithoutTax;
    }

    public BigDecimal getTaxAmount() {
        return taxAmount;
    }

    public void setTaxAmount(BigDecimal taxAmount) {
        this.taxAmount = taxAmount;
    }

    public BigDecimal getAmountWithTax() {
        return amountWithTax;
    }

    public void setAmountWithTax(BigDecimal amountWithTax) {
        this.amountWithTax = amountWithTax;
    }

    public String getCipherTextTwoCode() {
        return cipherTextTwoCode;
    }

    public void setCipherTextTwoCode(String cipherTextTwoCode) {
        this.cipherTextTwoCode = cipherTextTwoCode;
    }

    public String getCipherText() {
        return cipherText;
    }

    public void setCipherText(String cipherText) {
        this.cipherText = cipherText;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getCashierName() {
        return cashierName;
    }

    public void setCashierName(String cashierName) {
        this.cashierName = cashierName;
    }

    public String getCheckerName() {
        return checkerName;
    }

    public void setCheckerName(String checkerName) {
        this.checkerName = checkerName;
    }

    public String getInvoicerName() {
        return invoicerName;
    }

    public void setInvoicerName(String invoicerName) {
        this.invoicerName = invoicerName;
    }

    public String getCheckCode() { return checkCode; }

    public void setCheckCode(String checkCode) { this.checkCode = checkCode; }

    public String getMachineCode() {
        return machineCode;
    }

    public void setMachineCode(String machineCode) {
        this.machineCode = machineCode;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getOriginInvoiceNo() {
        return originInvoiceNo;
    }

    public void setOriginInvoiceNo(String originInvoiceNo) {
        this.originInvoiceNo = originInvoiceNo;
    }

    public String getOriginInvoiceCode() {
        return originInvoiceCode;
    }

    public void setOriginInvoiceCode(String originInvoiceCode) {
        this.originInvoiceCode = originInvoiceCode;
    }

    public String getRedNotificationNo() {
        return redNotificationNo;
    }

    public void setRedNotificationNo(String redNotificationNo) {
        this.redNotificationNo = redNotificationNo;
    }

    public String getSaleListFileFlag() {
        return saleListFileFlag;
    }

    public void setSaleListFileFlag(String saleListFileFlag) {
        this.saleListFileFlag = saleListFileFlag;
    }

    public String getPdfPath() {
        return pdfPath;
    }

    public void setPdfPath(String pdfPath) {
        this.pdfPath = pdfPath;
    }

    public List<SellerInvoiceItem> getDetails() {
        return details;
    }

    public void setDetails(List<SellerInvoiceItem> details) {
        this.details = details;
    }

    public String getDisplayPriceQuality() {
        return displayPriceQuality;
    }

    public void setDisplayPriceQuality(String displayPriceQuality) {
        this.displayPriceQuality = displayPriceQuality;
    }

    public String getProcessFlag() {
        return processFlag;
    }

    public void setProcessFlag(String processFlag) {
        this.processFlag = processFlag;
    }

    public String getProcessRemark() {
        return processRemark;
    }

    public void setProcessRemark(String processRemark) {
        this.processRemark = processRemark;
    }

    public String getSystemOrig() {
        return systemOrig;
    }

    public void setSystemOrig(String systemOrig) {
        this.systemOrig = systemOrig;
    }

    public String getSpecialFlag() {
        return specialFlag;
    }

    public void setSpecialFlag(String specialFlag) {
        this.specialFlag = specialFlag;
    }

    public List getSpecialAdditions() {
        return specialAdditions;
    }

    public void setSpecialAdditions(List specialAdditions) {
        this.specialAdditions = specialAdditions;
    }
}

==> invoice-client-4.2.1-20250102.034116-2-sources.jar: com/xforceplus/seller/invoice/client/model/adapter/SellerInvoice.java <==
package com.xforceplus.seller.invoice.client.model.adapter;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.collect.Lists;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

@SuppressWarnings({ "all", "unchecked", "rawtypes" })
public class SellerInvoice implements Serializable {

    private static final long serialVersionUID = -13752717;

    private String pid = "";
    private String settlementNo = "";
    private String invoiceType = "";
    private String invoiceCode = "";
    private String invoiceNo = "";
    private String paperDrewDate = "";
    private String sellerTaxNo = "";
    private String sellerName = "";
    private String sellerAddrTel = "";
    private String sellerAddress = "";
    private String sellerTel = "";
    private String sellerBankInfo = "";
    private String sellerBankName = "";
    private String sellerBankAccount = "";
    private String purchaserTaxNo = "";
    private String purchaserName = "";
    private String purchaserAddrTel = "";
    private String purchaserAddress = "";
    private String purchaserTel = "";
    private String purchaserBankInfo = "";
    private String purchaserBankName = "";
    private String purchaserBankAccount = "";
    private BigDecimal taxRate;
    private BigDecimal amountWithoutTax;
    private BigDecimal taxAmount;
    private BigDecimal amountWithTax;
    private String cipherTextTwoCode = "";
    private String cipherText = "";
    private String remark = "";
    private String cashierName = "";
    private String checkerName = "";
    private String invoicerName = "";
    private String checkCode = "";
    private String machineCode = "";
    private String status = "";
    private String displayPriceQuality = "";
    private String originInvoiceNo = "";
    private String originInvoiceCode = "";
    private String redNotificationNo = "";
    private String saleListFileFlag = "";
    private String pdfPath = "";
    private String processCode = "";
    private String processFlag = "";
    private String processRemark = "";
    /**
     * 2018年3月27日11:26:41 ykq 开票结算单新增SystemOrig
     * 发票协同需携带SystemOrig
     */
    private String systemOrig = "";
    private String ofdUrl;
    private String xmlUrl;
    private List<SellerInvoiceItem> details = Lists.newArrayList();
    private String specialFlag;

    public SellerInvoice() {

    }

    public String getProcessCode() {
        return processCode;
    }

    public void setProcessCode(String processCode) {
        this.processCode = processCode;
    }

    public String getOfdUrl() {
        return ofdUrl;
    }

    public void setOfdUrl(String ofdUrl) {
        this.ofdUrl = ofdUrl;
    }

    public String getXmlUrl() {
        return xmlUrl;
    }

    public void setXmlUrl(String xmlUrl) {
        this.xmlUrl = xmlUrl;
    }

    public String getPid() {
        return pid;
    }

    public void setPid(String pid) {
        this.pid = pid;
    }

    public String getSettlementNo() {
        return settlementNo;
    }

    public void setSettlementNo(String settlementNo) {
        this.settlementNo = settlementNo;
    }

    public String getInvoiceType() {
        return invoiceType;
    }

    public void setInvoiceType(String invoiceType) {
        this.invoiceType = invoiceType;
    }

    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }

    public String getInvoiceNo() {
        return invoiceNo;
    }

    public void setInvoiceNo(String invoiceNo) {
        this.invoiceNo = invoiceNo;
    }

    public String getPaperDrewDate() {
        return paperDrewDate;
    }

    public void setPaperDrewDate(String paperDrewDate) {
        this.paperDrewDate = paperDrewDate;
    }

    public String getSellerTaxNo() {
        return sellerTaxNo;
    }

    public void setSellerTaxNo(String sellerTaxNo) {
        this.sellerTaxNo = sellerTaxNo;
    }

    public String getSellerName() {
        return sellerName;
    }

    public void setSellerName(String sellerName) {
        this.sellerName = sellerName;
    }

    public String getSellerAddrTel() {
        return sellerAddrTel;
    }

    public void setSellerAddrTel(String sellerAddrTel) {
        this.sellerAddrTel = sellerAddrTel;
    }

    public String getSellerAddress() {
        return sellerAddress;
    }

    public void setSellerAddress(String sellerAddress) {
        this.sellerAddress = sellerAddress;
    }

    public String getSellerTel() {
        return sellerTel;
    }

    public void setSellerTel(String sellerTel) {
        this.sellerTel = sellerTel;
    }

    public String getSellerBankInfo() {
        return sellerBankInfo;
    }

    public void setSellerBankInfo(String sellerBankInfo) {
        this.sellerBankInfo = sellerBankInfo;
    }

    public String getSellerBankName() {
        return sellerBankName;
    }

    public void setSellerBankName(String sellerBankName) {
        this.sellerBankName = sellerBankName;
    }

    public String getSellerBankAccount() {
        return sellerBankAccount;
    }

    public void setSellerBankAccount(String sellerBankAccount) {
        this.sellerBankAccount = sellerBankAccount;
    }

    public String getPurchaserTaxNo() {
        return purchaserTaxNo;
    }

    public void setPurchaserTaxNo(String purchaserTaxNo) {
        this.purchaserTaxNo = purchaserTaxNo;
    }

    public String getPurchaserName() {
        return purchaserName;
    }

    public void setPurchaserName(String purchaserName) {
        this.purchaserName = purchaserName;
    }

    public String getPurchaserAddrTel() {
        return purchaserAddrTel;
    }

    public void setPurchaserAddrTel(String purchaserAddrTel) {
        this.purchaserAddrTel = purchaserAddrTel;
    }

    public String getPurchaserAddress() {
        return purchaserAddress;
    }

    public void setPurchaserAddress(String purchaserAddress) {
        this.purchaserAddress = purchaserAddress;
    }

    public String getPurchaserTel() {
        return purchaserTel;
    }

    public void setPurchaserTel(String purchaserTel) {
        this.purchaserTel = purchaserTel;
    }

    public String getPurchaserBankInfo() {
        return purchaserBankInfo;
    }

    public void setPurchaserBankInfo(String purchaserBankInfo) {
        this.purchaserBankInfo = purchaserBankInfo;
    }

    public String getPurchaserBankName() {
        return purchaserBankName;
    }

    public void setPurchaserBankName(String purchaserBankName) {
        this.purchaserBankName = purchaserBankName;
    }

    public String getPurchaserBankAccount() {
        return purchaserBankAccount;
    }

    public void setPurchaserBankAccount(String purchaserBankAccount) {
        this.purchaserBankAccount = purchaserBankAccount;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public BigDecimal getAmountWithoutTax() {
        return amountWithoutTax;
    }

    public void setAmountWithoutTax(BigDecimal amountWithoutTax) {
        this.amountWithoutTax = amountWithoutTax;
    }

    public BigDecimal getTaxAmount() {
        return taxAmount;
    }

    public void setTaxAmount(BigDecimal taxAmount) {
        this.taxAmount = taxAmount;
    }

    public BigDecimal getAmountWithTax() {
        return amountWithTax;
    }

    public void setAmountWithTax(BigDecimal amountWithTax) {
        this.amountWithTax = amountWithTax;
    }

    public String getCipherTextTwoCode() {
        return cipherTextTwoCode;
    }

    public void setCipherTextTwoCode(String cipherTextTwoCode) {
        this.cipherTextTwoCode = cipherTextTwoCode;
    }

    public String getCipherText() {
        return cipherText;
    }

    public void setCipherText(String cipherText) {
        this.cipherText = cipherText;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getCashierName() {
        return cashierName;
    }

    public void setCashierName(String cashierName) {
        this.cashierName = cashierName;
    }

    public String getCheckerName() {
        return checkerName;
    }

    public void setCheckerName(String checkerName) {
        this.checkerName = checkerName;
    }

    public String getInvoicerName() {
        return invoicerName;
    }

    public void setInvoicerName(String invoicerName) {
        this.invoicerName = invoicerName;
    }

    public String getCheckCode() { return checkCode; }

    public void setCheckCode(String checkCode) { this.checkCode = checkCode; }

    public String getMachineCode() {
        return machineCode;
    }

    public void setMachineCode(String machineCode) {
        this.machineCode = machineCode;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getOriginInvoiceNo() {
        return originInvoiceNo;
    }

    public void setOriginInvoiceNo(String originInvoiceNo) {
        this.originInvoiceNo = originInvoiceNo;
    }

    public String getOriginInvoiceCode() {
        return originInvoiceCode;
    }

    public void setOriginInvoiceCode(String originInvoiceCode) {
        this.originInvoiceCode = originInvoiceCode;
    }

    public String getRedNotificationNo() {
        return redNotificationNo;
    }

    public void setRedNotificationNo(String redNotificationNo) {
        this.redNotificationNo = redNotificationNo;
    }

    public String getSaleListFileFlag() {
        return saleListFileFlag;
    }

    public void setSaleListFileFlag(String saleListFileFlag) {
        this.saleListFileFlag = saleListFileFlag;
    }

    public String getPdfPath() {
        return pdfPath;
    }

    public void setPdfPath(String pdfPath) {
        this.pdfPath = pdfPath;
    }

    public List<SellerInvoiceItem> getDetails() {
        return details;
    }

    public void setDetails(List<SellerInvoiceItem> details) {
        this.details = details;
    }

    public String getDisplayPriceQuality() {
        return displayPriceQuality;
    }

    public void setDisplayPriceQuality(String displayPriceQuality) {
        this.displayPriceQuality = displayPriceQuality;
    }

    public String getProcessFlag() {
        return processFlag;
    }

    public void setProcessFlag(String processFlag) {
        this.processFlag = processFlag;
    }

    public String getProcessRemark() {
        return processRemark;
    }

    public void setProcessRemark(String processRemark) {
        this.processRemark = processRemark;
    }

    public String getSystemOrig() {
        return systemOrig;
    }

    public void setSystemOrig(String systemOrig) {
        this.systemOrig = systemOrig;
    }

    public String getSpecialFlag() {
        return specialFlag;
    }

    public void setSpecialFlag(String specialFlag) {
        this.specialFlag = specialFlag;
    }
}
